@@ -58,13 +58,11 @@ def htons(x):
     return (((x) << 8) & 0xFF00) | (((x) >> 8) & 0xFF)
 
 
-# pylint: disable=bad-whitespace
 SOCK_STREAM = const(0x21)  # TCP
 TCP_MODE = 80
 SOCK_DGRAM = const(0x02)  # UDP
 AF_INET = const(3)
 NO_SOCKET_AVAIL = const(255)
-# pylint: enable=bad-whitespace
 
 # keep track of sockets we allocate
 SOCKETS = []
@@ -77,6 +75,8 @@ def getaddrinfo(host, port, family=0, socktype=0, proto=0, flags=0):
     """
     if not isinstance(port, int):
         raise RuntimeError("Port must be an integer")
+    if is_ipv4(host):
+        return [(AF_INET, socktype, proto, "", (host, port))]
     return [(AF_INET, socktype, proto, "", (gethostbyname(host), port))]
 
 
@@ -90,6 +90,19 @@ def gethostbyname(hostname):
     return addr
 
 
+def is_ipv4(host):
+    """Checks if a host string is an IPv4 address.
+    :param str host: host's name or ip
+    """
+    octets = host.split(".", 3)
+    if len(octets) != 4 or not "".join(octets).isdigit():
+        return False
+    for octet in octets:
+        if int(octet) > 255:
+            return False
+    return True
+
+
 # pylint: disable=invalid-name
 class socket:
     """A simplified implementation of the Python 'socket' class
@@ -277,9 +290,7 @@ class socket:
         SOCKETS.remove(self.socknum)
 
     def available(self):
-        """Returns how many bytes of data are available to be read from the socket.
-
-        """
+        """Returns how many bytes of data are available to be read from the socket."""
         return _the_interface.socket_available(self.socknum, self._sock_type)
 
     def settimeout(self, value):
